Index: src/gpu/GrGpu.h |
diff --git a/src/gpu/GrGpu.h b/src/gpu/GrGpu.h |
index 4defa040d76d05f54d77602fedfce7ad0e390112..883b7ee98a91a1ff812c8be9f6c33464dfd6f021 100644 |
--- a/src/gpu/GrGpu.h |
+++ b/src/gpu/GrGpu.h |
@@ -280,9 +280,9 @@ |
size_t rowBytes); |
/** |
* Updates the pixels in a rectangle of a texture using a buffer |
* |
* @param textre The texture to write to. |
* @param left left edge of the rectangle to write (inclusive) |
* @param top top edge of the rectangle to write (inclusive) |
* @param width width of rectangle to write in pixels. |
@@ -293,7 +293,7 @@ |
* @param rowBytes number of bytes between consecutive rows. Zero |
* means rows are tightly packed. |
*/ |
- bool transferPixels(GrTexture* texture, |
+ bool transferPixels(GrSurface* surface, |
int left, int top, int width, int height, |
GrPixelConfig config, GrBuffer* transferBuffer, |
size_t offset, size_t rowBytes); |
@@ -579,8 +579,8 @@ |
GrPixelConfig config, |
const SkTArray<GrMipLevel>& texels) = 0; |
- // overridden by backend-specific derived class to perform the texture transfer |
- virtual bool onTransferPixels(GrTexture*, |
+ // overridden by backend-specific derived class to perform the surface write |
+ virtual bool onTransferPixels(GrSurface*, |
int left, int top, int width, int height, |
GrPixelConfig config, GrBuffer* transferBuffer, |
size_t offset, size_t rowBytes) = 0; |
@@ -280,9 +280,9 @@ |
size_t rowBytes); |
/** |
- * Updates the pixels in a rectangle of a texture using a buffer |
- * |
- * @param textre The texture to write to. |
+ * Updates the pixels in a rectangle of a surface using a buffer |
+ * |
+ * @param surface The surface to write to. |
* @param left left edge of the rectangle to write (inclusive) |
* @param top top edge of the rectangle to write (inclusive) |